@@ -1,3 +1,5 @@
+"""Tests for the BoundedSemaphore helper."""
+
 import random
 
 import pytest
@@ -9,6 +11,8 @@ from portalocker import utils
 @pytest.mark.parametrize('timeout', [None, 0, 0.001])
 @pytest.mark.parametrize('check_interval', [None, 0, 0.0005])
 def test_bounded_semaphore(timeout, check_interval, monkeypatch):
+    """Ensure that the semaphore honours *maximum*, *timeout* and
+    *check_interval* and raises AlreadyLocked when exhausted."""
     n = 2
     name: str = str(random.random())
     monkeypatch.setattr(utils, 'DEFAULT_TIMEOUT', 0.0001)
